PROGRAM compare


  IMPLICIT NONE

!**************************
! begin tex_ros_Precision
! KPP DP - Double precision kind
  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND(14,300)
! end tex_ros_Precision
!**************************

!**************************
! begin tex_ros_Parameters

! NSPEC - Number of chemical species
  INTEGER, PARAMETER :: NSPEC = 96 
! NVAR - Number of Variable species
  INTEGER, PARAMETER :: NVAR = 91 
! NVARACT - Number of Active species
  INTEGER, PARAMETER :: NVARACT = 88 
! NFIX - Number of Fixed species
  INTEGER, PARAMETER :: NFIX = 5 
! NREACT - Number of reactions
  INTEGER, PARAMETER :: NREACT1 = 233 
! LU_NONZERO - Number of nonzero entries in LU factoriz. of Jacobian
  INTEGER, PARAMETER :: LU_NONZERO = 1166 
! end tex_ros_Parameters
!**************************

!**************************
! begin grid_conf.f
     INTEGER, PARAMETER :: BLKSIZE = 50
 ! end grid_conf.f
!**************************

!**************************
! begin grparms.ext
      INTEGER NCS            ! # of chemical mechanisms used
      PARAMETER ( NCS = 1 )
      INTEGER NCS2           ! 2 * # of chemical mechanisms
      PARAMETER ( NCS2 = 2 * NCS )
! end grparms.ext
!**************************

!**************************
! begin grvars1.ext
      REAL*8 ZBOUND             ! Lower bound of zero threshold

! end grvars1.ext
!**************************

!**************************
! begin grvars2.ext
      INTEGER IRM2(   NRXNS, 3+MXPRD, NCS2 )  ! Mechanism reaction/species
                                              ! using new (sorted) species
                                              ! numbers                                             
      INTEGER NKUSERAT(    NRXNS, NCS2 )  ! Rxn numbers of active reactions
                                          ! in day and night  
      INTEGER NUSERAT(    NCS2 ) ! Number of active reactions in day and
                                 ! night mechanisms 
! end grvars2.ext
!**************************

!**************************
! begin grvars3.ext
      INTEGER NSUBFUN        ! Number of RHS evaluations
      INTEGER ISCHAN         ! Number of species in [P]
      INTEGER NUMCELLS       ! Number of cells in block being processed
      INTEGER NCSP           ! Day/night mechanism index;
                             ! = NCS ===>day; = NCS+1 ===>night      
      REAL*8 CNEW(    BLKSIZE,  N_GC_SPC )  ! Species conc. for cells in block
                                            ! in sorted species order (ppm)
      REAL*8 EMBLK(   BLKSIZE,  N_GC_SPC )  ! Species emissions in each cell
      REAL*8 GLOSS(   BLKSIZE,  N_GC_SPC )  ! dc/dt for each species (i.e., RHS)
      REAL*8 RK(      BLKSIZE,     NRXNS )  ! Rate const. for each cell
      REAL*8 RXRAT(   BLKSIZE,     NRXNS )  ! Reaction rates for each cell
! end grvars3.ext
!**************************



! A - Rate for each equation
  REAL(kind=dp) :: A(NREACT1)




CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Fun - time derivatives of variables - Agregate form
!   Arguments :
!      V         - Concentrations of variable species (local)
!      F         - Concentrations of fixed species (local)
!      RCT       - Rate constants (local)
!      Vdot      - Time derivative of variable species concentrations
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE Fun ( V, F, RCT, Vdot )

! V - Concentrations of variable species (local)
  REAL(kind=dp) :: V(NVAR)
! F - Concentrations of fixed species (local)
  REAL(kind=dp) :: F(NFIX)
! RCT - Rate constants (local)
  REAL(kind=dp) :: RCT(NREACT1)
! Vdot - Time derivative of variable species concentrations
  REAL(kind=dp) :: Vdot(NVAR)


! Computation of equation rates
  A(1) = V(89)
  A(2) = RCT(2)*V(73)*F(1)*F(2)
  A(3) = 8e-12*V(73)*V(79)
  A(4) = RCT(4)*V(73)*V(90)*F(1)
  A(5) = 6.5e-12*V(73)*V(89)
  A(6) = RCT(6)*V(73)*V(89)
  A(7) = 1.8e-12*V(79)*V(90)
  A(8) = 1.4e-13*V(79)*V(89)
  A(9) = 1.8e-11*V(80)*V(90)
  A(10) = 3.3e-39*V(90)*V(90)*F(2)
  A(11) = RCT(11)*V(80)*V(89)
  A(12) = RCT(12)*V(12)
  A(13) = 2.6e-22*V(12)*F(3)
  A(14) = 4.5e-14*V(80)*V(89)
  A(15) = V(80)
  A(16) = V(80)
  A(17) = V(79)
  A(18) = V(79)
  A(19) = 2.2e-10*V(4)*F(3)
  A(20) = 2.09e-11*V(4)*F(1)
  A(21) = RCT(21)*V(88)*V(90)
  A(22) = V(17)
  A(23) = V(17)
  A(24) = 2.7e-12*V(17)*V(88)
  A(25) = RCT(25)*V(88)*V(89)
  A(26) = 2e-11*V(80)*V(88)
  A(27) = 7.2e-15*V(59)*V(88)
  A(28) = V(59)
  A(29) = 1.3e-13*V(55)*V(88)
  A(30) = 1.9e-12*V(79)*V(88)
  A(31) = 3.4e-12*V(84)*V(90)
  A(32) = RCT(32)*V(84)*V(89)
  A(33) = 4.1e-05*V(41)
  A(34) = V(41)
  A(35) = 1.5e-12*V(41)*V(88)
  A(36) = 1.4e-14*V(79)*V(84)
  A(37) = 2.2e-13*V(84)*V(84)
  A(38) = 3.08e-34*V(84)*V(84)*F(3)
  A(39) = 4e-12*V(80)*V(84)
  A(40) = 8.5e-13*V(80)*V(80)
  A(41) = V(7)
  A(42) = 2.9e-12*V(7)*V(88)
  A(43) = 4.8e-11*V(84)*V(88)
  A(44) = RCT(44)*V(5)*V(88)
  A(45) = 7.7e-12*V(88)*F(4)
  A(46) = 2.8e-12*V(86)*V(90)
  A(47) = 3.8e-13*V(84)*V(86)
  A(48) = 1.3e-12*V(80)*V(86)
  A(49) = 2.45e-14*V(86)*V(86)
  A(50) = 5.9e-13*V(86)*V(86)
  A(51) = 2.7e-12*V(87)*V(90)
  A(52) = 1.9e-13*V(84)*V(87)
  A(53) = 2.3e-12*V(80)*V(87)
  A(54) = 2e-13*V(86)*V(87)
  A(55) = 3.5e-14*V(87)*V(87)
  A(56) = V(63)*V(90)
  A(57) = V(63)*V(84)
  A(58) = V(63)*V(80)
  A(59) = V(63)*V(86)
  A(60) = V(63)*V(87)
  A(61) = V(63)*V(63)
  A(62) = V(83)*V(90)
  A(63) = V(83)*V(84)
  A(64) = V(83)*V(86)
  A(65) = V(80)*V(83)
  A(66) = V(83)*V(87)
  A(67) = V(63)*V(83)
  A(68) = V(83)*V(83)
  A(69) = RCT(69)*V(82)*V(89)
  A(70) = 0.0049*V(8)
  A(71) = 7.8e-12*V(82)*V(90)
  A(72) = 4.3e-13*V(82)*V(84)
  A(73) = 4e-12*V(80)*V(82)
  A(74) = 1.8e-12*V(82)*V(86)
  A(75) = 7.5e-12*V(82)*V(87)
  A(76) = V(63)*V(82)
  A(77) = V(82)*V(83)
  A(78) = 2.9e-12*V(82)*V(82)
  A(79) = RCT(79)*V(85)*V(89)
  A(80) = 2e+15*V(9)
  A(81) = 1.25e-11*V(85)*V(90)
  A(82) = V(84)*V(85)
  A(83) = V(80)*V(85)
  A(84) = V(85)*V(86)
  A(85) = V(85)*V(87)
  A(86) = V(63)*V(85)
  A(87) = V(83)*V(85)
  A(88) = V(82)*V(85)
  A(89) = V(85)*V(85)
  A(90) = 1.37e-11*V(89)*V(91)
  A(91) = 7.9e+16*V(10)
  A(92) = V(90)*V(91)
  A(93) = V(84)*V(91)
  A(94) = V(80)*V(91)
  A(95) = V(86)*V(91)
  A(96) = V(87)*V(91)
  A(97) = V(63)*V(91)
  A(98) = V(83)*V(91)
  A(99) = V(82)*V(91)
  A(100) = V(85)*V(91)
  A(101) = V(91)*V(91)
  A(102) = V(81)*V(89)
  A(103) = 1.6e+16*V(11)
  A(104) = V(81)*V(90)
  A(105) = V(81)*V(84)
  A(106) = V(80)*V(81)
  A(107) = V(81)*V(86)
  A(108) = V(81)*V(87)
  A(109) = V(63)*V(81)
  A(110) = V(81)*V(83)
  A(111) = V(81)*V(82)
  A(112) = V(81)*V(85)
  A(113) = V(81)*V(91)
  A(114) = V(81)*V(81)
  A(115) = 2.4e-11*V(32)*V(89)
  A(116) = 7.5e+14*V(32)
  A(117) = 2.3e-11*V(62)*V(89)
  A(118) = V(62)*V(84)
  A(119) = 0.001*V(62)
  A(120) = V(37)*V(89)
  A(121) = V(37)*V(84)
  A(122) = V(37)
  A(123) = V(72)
  A(124) = V(72)
  A(125) = 8.6e-12*V(72)*V(88)
  A(126) = 9.7e-15*V(72)*V(84)
  A(127) = 2.4e+12*V(49)
  A(128) = V(49)*V(90)
  A(129) = 2e-12*V(72)*V(80)
  A(130) = 5.6e-12*V(75)*V(88)
  A(131) = V(75)
  A(132) = 1.4e-12*V(75)*V(80)
  A(133) = 2e-11*V(77)*V(88)
  A(134) = V(77)
  A(135) = 1.4e-12*V(77)*V(80)
  A(136) = 1.1e-12*V(57)*V(88)
  A(137) = V(57)
  A(138) = RCT(138)*V(76)*V(88)
  A(139) = 0.15*V(76)
  A(140) = RCT(140)*V(39)*V(88)
  A(141) = 2.9e-12*V(38)*V(88)
  A(142) = V(38)
  A(143) = 1.1e-11*V(51)*V(88)
  A(144) = V(51)
  A(145) = V(60)
  A(146) = 0.006*V(60)
  A(147) = 1.1e-11*V(60)*V(88)
  A(148) = 2.8e-12*V(60)*V(80)
  A(149) = V(56)
  A(150) = 1.5e-11*V(56)*V(88)
  A(151) = 1.4e-12*V(56)*V(80)
  A(152) = V(18)
  A(153) = 2.63e-11*V(53)*V(88)
  A(154) = 3.78e-12*V(53)*V(80)
  A(155) = 4.2e-11*V(46)*V(88)
  A(156) = 1.37e-11*V(46)*V(80)
  A(157) = V(52)*V(80)
  A(158) = 1.29e-11*V(50)*V(88)
  A(159) = 0.05*V(50)
  A(160) = 1.4e-12*V(50)*V(80)
  A(161) = 1.86e-11*V(66)*V(88)
  A(162) = 1.36e-15*V(66)*V(79)
  A(163) = 1.5e-12*V(66)*V(80)
  A(164) = 6.34e-12*V(66)*V(73)
  A(165) = 0.0041*V(66)
  A(166) = 4.14e-12*V(71)*V(88)
  A(167) = 7.51e-16*V(71)*V(79)
  A(168) = 4.32e-12*V(71)*V(73)
  A(169) = 0.0021*V(71)
  A(170) = 6.19e-11*V(69)*V(88)
  A(171) = 4.18e-18*V(69)*V(79)
  A(172) = 1e-13*V(69)*V(80)
  A(173) = 0.0041*V(69)
  A(174) = 1.5e-11*V(78)*V(88)
  A(175) = 0.02*V(78)
  A(176) = 7.8e-12*V(74)*V(88)
  A(177) = V(74)
  A(178) = 5e-11*V(48)*V(88)
  A(179) = 2e-18*V(48)*V(79)
  A(180) = 5e-11*V(44)*V(88)
  A(181) = 0.365*V(44)
  A(182) = 5e-11*V(45)*V(88)
  A(183) = 7.28*V(45)
  A(184) = 2.15e-12*V(88)*F(5)
  A(185) = 1.96e-12*V(58)*V(88)
  A(186) = 9.14e-15*V(58)*V(79)
  A(187) = RCT(187)*V(58)*V(80)
  A(188) = 1.04e-11*V(58)*V(73)
  A(189) = 2.5e-11*V(65)*V(88)
  A(190) = 7.86e-15*V(65)*V(79)
  A(191) = 3.03e-12*V(65)*V(80)
  A(192) = 3.6e-11*V(65)*V(73)
  A(193) = 1.83e-11*V(64)*V(88)
  A(194) = 1.08e-15*V(64)*V(79)
  A(195) = 3.66e-12*V(64)*V(80)
  A(196) = 3.27e-11*V(64)*V(73)
  A(197) = RCT(197)*V(6)*V(88)
  A(198) = 9.87e-12*V(19)*V(88)
  A(199) = 1.02e-11*V(20)*V(88)
  A(200) = 5.95e-12*V(47)*V(88)
  A(201) = 1.11e-11*V(21)*V(88)
  A(202) = 6e-12*V(22)*V(88)
  A(203) = 2.487e-11*V(40)*V(88)
  A(204) = 7.1e-12*V(68)*V(88)
  A(205) = 2.62e-15*V(68)*V(79)
  A(206) = 4.45e-14*V(68)*V(80)
  A(207) = 1.07e-11*V(68)*V(73)
  A(208) = 1.74e-11*V(70)*V(88)
  A(209) = 5.02e-16*V(70)*V(79)
  A(210) = 7.26e-13*V(70)*V(80)
  A(211) = 2.09e-11*V(70)*V(73)
  A(212) = 4.5e-13*V(54)*V(88)
  A(213) = 8e-13*V(61)*V(88)
  A(214) = 1.16e-12*V(67)*V(88)
  A(215) = 2.471e-12*V(13)*V(88)
  A(216) = 1.81e-12*V(33)*V(88)
  A(217) = 1.43e-11*V(23)*V(88)
  A(218) = 2.36e-11*V(34)*V(88)
  A(219) = 1.37e-11*V(42)*V(88)
  A(220) = 7.1e-12*V(24)*V(88)
  A(221) = 3.27e-11*V(43)*V(88)
  A(222) = 3.25e-11*V(35)*V(88)
  A(223) = 5.75e-11*V(25)*V(88)
  A(224) = 7.7e-13*V(14)*V(88)
  A(225) = 1.5e-13*V(15)*V(88)
  A(226) = 6.5e-12*V(26)*V(88)
  A(227) = 6e-12*V(27)*V(88)
  A(228) = 6e-12*V(28)*V(88)
  A(229) = 1.07e-12*V(29)*V(88)
  A(230) = 7.68e-11*V(30)*V(88)
  A(231) = 5.55e-13*V(16)*V(88)
  A(232) = 5.2e-11*V(36)*V(88)
  A(233) = RCT(233)*V(31)*V(88)

! Aggregate function
  Vdot(1) = A(44)
  Vdot(2) = 0.75*A(72)
  Vdot(3) = 0.75*A(82)+0.75*A(93)+0.75*A(105)
  Vdot(4) = A(18)-A(19)-A(20)
  Vdot(5) = -A(44)
  Vdot(6) = -A(197)
  Vdot(7) = A(37)+A(38)-A(41)-A(42)
  Vdot(8) = A(69)-A(70)
  Vdot(9) = A(79)-A(80)
  Vdot(10) = A(90)-A(91)
  Vdot(11) = A(102)-A(103)
  Vdot(12) = A(11)-A(12)-A(13)
  Vdot(13) = -A(215)
  Vdot(14) = -A(224)
  Vdot(15) = -A(225)
  Vdot(16) = -A(231)
  Vdot(17) = A(21)-A(22)-A(23)-A(24)
  Vdot(18) = -A(152)+0.031*A(194)+0.087*A(203)+0.185*A(214)+0.139*A(219)+0.383*A(221)+0.079*A(222)
  Vdot(19) = -A(198)
  Vdot(20) = -A(199)
  Vdot(21) = -A(201)
  Vdot(22) = -A(202)
  Vdot(23) = -A(217)
  Vdot(24) = -A(220)
  Vdot(25) = -A(223)
  Vdot(26) = -A(226)
  Vdot(27) = -A(227)
  Vdot(28) = -A(228)
  Vdot(29) = -A(229)
  Vdot(30) = -A(230)
  Vdot(31) = -A(233)
  Vdot(32) = -A(115)-A(116)+0.236*A(199)+0.016*A(233)
  Vdot(33) = -A(216)
  Vdot(34) = -A(218)
  Vdot(35) = -A(222)
  Vdot(36) = -A(232)
  Vdot(37) = -A(120)-A(121)-A(122)+A(157)
  Vdot(38) = A(47)-A(141)-A(142)
  Vdot(39) = A(49)+0.25*A(54)+0.25*A(64)-A(140)
  Vdot(40) = -A(203)
  Vdot(41) = A(32)-A(33)-A(34)-A(35)
  Vdot(42) = -A(219)
  Vdot(43) = -A(221)
  Vdot(44) = -A(180)-A(181)+0.086*A(203)+0.156*A(216)+0.29*A(218)+0.06*A(219)+0.077*A(221)+0.097*A(223)+0.049*A(229)&
               &+0.103*A(230)+0.076*A(232)
  Vdot(45) = -A(182)-A(183)+0.049*A(202)+0.09*A(203)+0.057*A(216)+0.012*A(217)+0.108*A(218)+0.145*A(219)+0.049*A(220)&
               &+0.149*A(221)+0.027*A(222)+0.114*A(223)+0.049*A(226)+0.049*A(227)+0.049*A(228)+0.049*A(229)+0.103*A(230)&
               &+0.076*A(232)
  Vdot(46) = -A(155)-A(156)+0.19*A(202)+0.185*A(203)+0.234*A(216)+0.188*A(217)+0.21*A(218)+0.161*A(219)+0.19*A(220)&
               &+0.186*A(221)+0.186*A(222)+0.186*A(223)+0.19*A(226)+0.19*A(227)+0.19*A(228)+0.236*A(230)+0.236*A(232)
  Vdot(47) = -A(200)
  Vdot(48) = -A(178)-A(179)+0.498*A(202)+0.578*A(203)+0.764*A(215)+0.46*A(216)+0.709*A(217)+0.347*A(218)+0.572*A(219)&
               &+0.498*A(220)+0.533*A(221)+0.733*A(222)+0.569*A(223)+0.764*A(224)+0.764*A(225)+0.498*A(226)+0.498*A(227)&
               &+0.498*A(228)+0.117*A(229)+0.764*A(231)+0.003*A(232)
  Vdot(49) = A(126)-A(127)-A(128)
  Vdot(50) = -A(158)-A(159)-A(160)+0.052*A(203)+0.061*A(208)+0.042*A(209)+0.015*A(210)+0.085*A(216)+0.083*A(217)+0.037&
               &*A(218)+0.054*A(219)+0.044*A(221)+0.044*A(222)+0.025*A(223)
  Vdot(51) = A(52)+A(63)-A(143)-A(144)
  Vdot(52) = A(117)+A(121)+A(122)-A(157)
  Vdot(53) = A(118)+A(119)-A(153)-A(154)+0.236*A(215)+0.236*A(224)+0.236*A(225)+0.236*A(229)+0.236*A(231)
  Vdot(54) = A(128)+0.333*A(162)+0.351*A(167)+0.1*A(171)+0.37*A(186)+0.204*A(190)+0.103*A(194)+0.121*A(198)+0.185*A(205)&
               &+0.073*A(209)-A(212)
  Vdot(55) = -A(29)+A(123)+A(124)+A(125)+A(129)+A(131)+0.034*A(133)+A(134)+2*A(145)+A(146)+1.26*A(147)+1.26*A(148)&
               &+A(149)+A(150)+A(151)+0.416*A(161)+0.45*A(162)+0.5*A(163)+0.67*A(165)+0.475*A(167)+0.7*A(169)+0.336*A(170)&
               &+0.498*A(171)+0.572*A(172)+1.233*A(173)+A(178)+1.5*A(179)+A(181)+A(183)+0.5*A(186)+0.491*A(188)+0.275*A(190)&
               &+0.157*A(194)+0.16*A(198)+0.002*A(200)+0.345*A(205)+0.265*A(209)+0.012*A(211)
  Vdot(56) = -A(149)-A(150)-A(151)+0.23*A(155)+0.084*A(161)+0.9*A(162)+0.3*A(166)+0.95*A(167)+0.174*A(170)+0.742*A(171)&
               &+0.008*A(172)+0.5*A(181)+0.5*A(183)+0.109*A(202)+0.274*A(203)+0.13*A(213)+0.135*A(216)+0.112*A(217)+0.335&
               &*A(218)+0.238*A(219)+0.109*A(220)+0.166*A(221)+0.364*A(222)+0.621*A(223)+0.109*A(226)+0.109*A(227)+0.109&
               &*A(228)+0.076*A(230)+0.038*A(232)
  Vdot(57) = A(116)-A(136)-A(137)+0.006*A(176)+0.02*A(177)+0.13*A(194)+0.417*A(198)+0.024*A(199)+0.452*A(200)+0.072&
               &*A(201)+0.005*A(204)+0.001*A(205)+0.024*A(206)+0.127*A(208)+0.045*A(209)+0.102*A(210)+0.024*A(233)
  Vdot(58) = -A(185)-A(186)-A(187)-A(188)
  Vdot(59) = 2*A(13)+A(25)-A(27)-A(28)+0.2*A(39)+A(129)+A(132)+A(135)+A(148)+A(151)+A(154)+A(156)+A(157)+A(160)+0.5&
               &*A(163)+0.15*A(172)
  Vdot(60) = -A(145)-A(146)-A(147)-A(148)+0.23*A(153)+0.15*A(170)+0.023*A(171)+A(179)+0.5*A(181)+0.5*A(183)+0.009*A(188)&
               &+0.001*A(194)+0.248*A(198)+0.094*A(202)+0.1*A(203)+0.207*A(215)+0.116*A(216)+0.195*A(217)+0.107*A(218)+0.084&
               &*A(219)+0.094*A(220)+0.065*A(221)+0.063*A(222)+0.207*A(224)+0.207*A(225)+0.094*A(226)+0.094*A(227)+0.094&
               &*A(228)+0.084*A(229)+0.084*A(230)+0.207*A(231)+0.084*A(232)
  Vdot(61) = 0.25*A(72)+A(74)+A(75)+A(77)+0.05*A(205)+0.129*A(209)-A(213)
  Vdot(62) = A(92)+A(94)+A(99)+A(100)+2*A(101)+A(113)-A(117)-A(118)-A(119)+0.24*A(153)+A(154)+0.24*A(155)+A(156)
  Vdot(63) = -A(56)-A(57)-A(58)-A(59)-A(60)-2*A(61)-A(67)-A(76)-A(86)+A(92)+A(94)-A(97)+A(99)+A(100)+2*A(101)-A(109)&
               &+A(113)+A(136)+0.616*A(138)+0.675*A(166)+0.515*A(175)+0.596*A(176)+0.152*A(177)+A(180)+A(181)+A(182)+A(183)&
               &+0.079*A(189)+0.126*A(190)+0.187*A(191)+0.24*A(192)+0.5*A(193)+0.729*A(194)+0.75*A(195)+0.559*A(199)+0.936&
               &*A(200)+0.948*A(201)+0.205*A(204)+0.488*A(206)+0.001*A(208)+0.137*A(209)+0.711*A(210)+0.381*A(233)
  Vdot(64) = -A(193)-A(194)-A(195)-A(196)
  Vdot(65) = -A(189)-A(190)-A(191)-A(192)
  Vdot(66) = -A(161)-A(162)-A(163)-A(164)-A(165)+0.23*A(189)+0.39*A(190)+0.025*A(208)+0.026*A(209)+0.012*A(211)
  Vdot(67) = 0.25*A(82)+A(84)+A(85)+A(87)+0.25*A(93)+A(95)+A(96)+A(98)+0.25*A(105)+A(107)+A(108)+2*A(110)+0.372*A(171)&
               &+0.15*A(190)+0.189*A(194)+0.119*A(205)+0.303*A(209)-A(214)
  Vdot(68) = -A(204)-A(205)-A(206)-A(207)
  Vdot(69) = -A(170)-A(171)-A(172)-A(173)+0.357*A(189)+0.936*A(191)+0.025*A(208)
  Vdot(70) = -A(208)-A(209)-A(210)-A(211)
  Vdot(71) = -A(166)-A(167)-A(168)-A(169)+0.32*A(189)+0.16*A(190)+0.048*A(210)
  Vdot(72) = A(46)+A(48)+A(49)+2*A(50)+0.75*A(54)+0.75*A(64)+A(74)+A(84)+A(95)+A(104)+A(106)+A(107)+A(111)+A(112)+A(113)&
               &+2*A(114)-A(123)-A(124)-A(125)-A(126)+A(127)-A(129)+A(136)+0.115*A(138)+A(140)+0.35*A(141)+A(142)+A(146)&
               &+0.084*A(161)+0.2*A(162)+0.67*A(165)+0.3*A(166)+0.1*A(167)+0.055*A(170)+0.125*A(171)+0.227*A(172)+0.3*A(173)&
               &+0.213*A(174)+0.506*A(175)+0.01*A(176)+0.134*A(177)+1.61*A(185)+A(186)+0.191*A(188)+0.624*A(189)+0.592&
               &*A(190)+0.24*A(192)+0.276*A(193)+0.235*A(194)+0.039*A(198)+0.026*A(199)+0.024*A(200)+0.026*A(201)+0.732&
               &*A(204)+0.5*A(205)+0.244*A(208)+0.269*A(209)+0.079*A(210)+0.234*A(233)
  Vdot(73) = A(1)-A(2)-A(3)-A(4)-A(5)-A(6)+A(16)+A(17)+A(20)-A(164)-A(168)-A(188)-A(192)-A(196)-A(207)-A(211)
  Vdot(74) = A(62)+A(115)+0.572*A(172)-0.69*A(176)-A(177)+0.276*A(195)+0.511*A(206)+0.321*A(210)
  Vdot(75) = A(81)+A(83)+A(88)+2*A(89)+A(100)+A(112)-A(130)-A(131)-A(132)+0.034*A(133)+A(134)+0.482*A(138)+A(139)+0.129&
               &*A(170)+0.047*A(171)+0.467*A(173)+0.084*A(174)+0.246*A(175)+0.439*A(176)+0.431*A(177)+0.195*A(185)+0.25&
               &*A(188)+A(197)+0.445*A(199)+0.455*A(200)+0.099*A(201)+0.294*A(204)+0.154*A(205)+0.009*A(206)+0.732*A(208)&
               &+0.456*A(209)+0.507*A(210)+0.605*A(214)
  Vdot(76) = 0.5*A(64)+A(65)+0.5*A(66)+A(68)-A(138)-A(139)+0.416*A(161)+0.55*A(168)+0.15*A(170)+0.21*A(171)+0.233*A(173)&
               &+0.115*A(174)+0.177*A(176)+0.243*A(177)+0.332*A(199)+0.11*A(200)+0.089*A(201)+0.437*A(207)+0.072*A(208)&
               &+0.026*A(209)+0.001*A(210)+0.659*A(211)+0.719*A(233)
  Vdot(77) = -A(133)-A(134)-A(135)+0.37*A(138)+A(143)+A(144)+A(164)+0.675*A(166)+0.45*A(168)+0.013*A(170)+0.218*A(172)&
               &+0.558*A(174)+0.71*A(175)+0.213*A(176)+0.147*A(177)+A(178)+A(180)+A(182)+A(187)+0.474*A(193)+0.205*A(194)&
               &+0.474*A(195)+0.147*A(196)+0.155*A(198)+0.122*A(199)+0.244*A(200)+0.204*A(201)+0.497*A(204)+0.363*A(205)&
               &+0.037*A(206)+0.45*A(207)+0.511*A(208)+0.305*A(209)+0.151*A(210)+0.069*A(211)+0.21*A(214)
  Vdot(78) = 0.5*A(64)+0.5*A(66)+A(68)+A(77)+A(87)+A(98)+0.7*A(169)+0.332*A(170)-0.671*A(174)-A(175)+0.048*A(176)+0.435&
               &*A(177)+0.1*A(190)+0.75*A(192)+0.276*A(193)+0.276*A(194)+0.853*A(196)+0.125*A(200)+0.417*A(201)+0.239*A(202)&
               &+0.119*A(204)+0.215*A(205)+0.113*A(207)+0.006*A(209)+0.259*A(211)+0.239*A(220)+0.239*A(226)+0.239*A(227)&
               &+0.239*A(228)+0.007*A(233)
  Vdot(79) = A(2)-A(3)-A(7)-A(8)-A(17)-A(18)-A(30)-A(36)+0.25*A(72)+0.25*A(82)+0.25*A(93)+0.25*A(105)-A(162)-A(167)&
               &-A(171)-A(179)-A(186)-A(190)-A(194)-A(205)-A(209)
  Vdot(80) = A(6)+A(8)-A(9)-A(11)+A(12)-A(14)-A(15)-A(16)-A(26)+A(27)+0.39*A(34)-A(39)-2*A(40)-A(48)-A(53)-A(58)-A(65)&
               &-A(73)-A(83)-A(94)-A(106)-A(129)-A(132)-A(135)-A(148)-A(151)-A(154)-A(156)-A(157)-A(160)-A(163)-A(172)&
               &-A(187)-A(191)-A(195)-A(206)-A(210)
  Vdot(81) = -A(102)+A(103)-A(104)-A(105)-A(106)-A(107)-A(108)-A(110)-A(111)-A(112)-A(113)-2*A(114)+0.5*A(161)+0.5&
               &*A(163)+0.33*A(165)+0.3*A(169)+0.289*A(170)+0.15*A(172)+0.192*A(190)+0.24*A(192)
  Vdot(82) = -A(69)+A(70)-A(71)-A(72)-A(73)-A(74)-A(75)-A(77)-2*A(78)-A(88)-A(99)+A(104)+A(106)+A(112)+A(113)+2*A(114)&
               &+A(130)+A(132)+A(136)+A(137)+0.492*A(138)+A(139)+A(149)+A(150)+A(151)+2*A(152)+0.67*A(165)+0.675*A(166)&
               &+0.467*A(173)+0.029*A(174)+0.667*A(175)+A(180)+0.5*A(181)+A(182)+0.5*A(183)+0.123*A(194)+0.011*A(200)+0.137&
               &*A(209)
  Vdot(83) = -A(62)-A(63)-A(64)-A(65)-A(66)-2*A(68)-A(77)-A(87)-A(98)-A(110)+0.001*A(133)+0.042*A(138)+0.025*A(166)&
               &+0.041*A(170)+0.051*A(172)+0.07*A(174)+0.04*A(175)+0.173*A(176)+0.095*A(177)+0.093*A(189)+0.008*A(190)+0.064&
               &*A(191)+0.01*A(192)+0.25*A(193)+0.18*A(194)+0.25*A(195)+0.021*A(198)+0.07*A(199)+0.143*A(200)+0.347*A(201)&
               &+0.024*A(202)+0.009*A(203)+0.09*A(204)+0.001*A(205)+0.176*A(206)+0.082*A(208)+0.002*A(209)+0.136*A(210)&
               &+0.001*A(211)+0.008*A(216)+0.008*A(217)+0.008*A(218)+0.008*A(219)+0.024*A(220)+0.01*A(221)+0.01*A(222)+0.01&
               &*A(223)+0.024*A(226)+0.024*A(227)+0.024*A(228)+0.07*A(229)+0.07*A(230)+0.07*A(232)+0.078*A(233)
  Vdot(84) = A(23)+A(26)+A(29)+A(30)-A(31)-A(32)+A(33)+0.61*A(34)-A(36)-2*A(37)-2*A(38)-A(39)+A(42)-A(43)+A(44)+A(45)&
               &+A(46)-A(47)+A(48)+2*A(50)+A(51)-A(52)+A(53)+A(54)+A(55)-A(63)+A(64)+A(65)+A(66)+A(68)-A(72)-A(82)-A(93)&
               &-A(105)-A(118)-A(121)+2*A(123)+A(125)-A(126)+A(127)+A(128)+A(129)+A(131)+A(134)+A(140)+A(142)+A(144)+2&
               &*A(145)+0.63*A(147)+0.63*A(148)+A(149)+0.008*A(162)+0.34*A(165)+0.064*A(167)+0.4*A(171)+1.233*A(173)+0.379&
               &*A(174)+0.113*A(176)+0.341*A(177)+1.5*A(179)+0.5*A(181)+0.5*A(183)+0.12*A(186)+0.5*A(188)+0.033*A(194)+0.121&
               &*A(198)+0.19*A(202)+0.185*A(203)+0.056*A(205)+0.003*A(209)+0.013*A(211)+A(212)+0.236*A(215)+0.234*A(216)&
               &+0.188*A(217)+0.21*A(218)+0.161*A(219)+0.19*A(220)+0.186*A(221)+0.186*A(222)+0.186*A(223)+0.236*A(224)+0.236&
               &*A(225)+0.19*A(226)+0.19*A(227)+0.19*A(228)+0.236*A(229)+0.236*A(230)+0.236*A(231)+0.236*A(232)
  Vdot(85) = -A(79)+A(80)-A(81)-A(82)-A(83)-A(84)-A(85)-A(87)-A(88)-2*A(89)-A(100)-A(112)+0.965*A(133)+A(135)+0.096&
               &*A(138)+0.37*A(147)+0.37*A(148)+0.1*A(162)+0.05*A(167)+0.048*A(171)+0.3*A(173)+0.049*A(174)+0.333*A(175)&
               &+0.201*A(194)+0.006*A(209)+0.479*A(229)+0.6*A(230)+0.539*A(232)
  Vdot(86) = -A(46)-A(47)-A(48)-2*A(49)-2*A(50)-A(54)-A(64)+A(71)+A(73)-A(74)+2*A(78)-A(84)+A(88)-A(95)+A(99)-A(107)&
               &+A(111)+A(116)+A(131)+A(137)+0.65*A(141)+0.3*A(169)+A(184)+0.3*A(188)+0.25*A(192)+0.011*A(200)+0.076*A(205)&
               &+0.197*A(209)+0.03*A(210)+0.87*A(213)+0.162*A(233)
  Vdot(87) = -A(51)-A(52)-A(53)-A(54)-2*A(55)-A(66)-A(75)+A(81)+A(83)-A(85)+A(88)+2*A(89)-A(96)+A(100)-A(108)+A(112)&
               &+0.034*A(133)+A(134)+0.37*A(138)+A(139)+0.34*A(143)+0.76*A(153)+0.76*A(155)+0.5*A(161)+0.1*A(162)+0.5*A(163)&
               &+0.33*A(165)+0.3*A(166)+0.05*A(167)+0.67*A(170)+0.048*A(171)+0.799*A(172)+0.473*A(174)+0.96*A(175)+0.376&
               &*A(176)+0.564*A(177)+A(178)+A(181)+A(183)+A(185)+A(187)+0.2*A(188)+0.907*A(189)+0.066*A(190)+0.749*A(191)&
               &+0.75*A(193)+0.031*A(194)+0.276*A(195)+A(197)+0.612*A(198)+0.695*A(199)+0.835*A(200)+0.653*A(201)+0.786&
               &*A(202)+0.806*A(203)+0.91*A(204)+0.022*A(205)+0.824*A(206)+0.918*A(208)+0.033*A(209)+0.442*A(210)+0.012&
               &*A(211)+0.13*A(213)+A(214)+0.764*A(215)+0.758*A(216)+0.804*A(217)+0.782*A(218)+0.831*A(219)+0.786*A(220)&
               &+0.804*A(221)+0.804*A(222)+0.804*A(223)+0.764*A(224)+0.764*A(225)+0.786*A(226)+0.786*A(227)+0.786*A(228)&
               &+0.215*A(229)+0.094*A(230)+0.764*A(231)+0.155*A(232)+0.743*A(233)
  Vdot(88) = 2*A(19)-A(21)+A(22)-A(24)-A(25)-A(26)-A(27)+A(28)-A(29)-A(30)+A(31)+0.39*A(34)-A(35)+A(36)+0.8*A(39)+2&
               &*A(41)-A(42)-A(43)-A(44)-A(45)-A(125)-A(130)-A(133)-A(136)-A(138)-A(140)-0.65*A(141)+A(142)-0.34*A(143)&
               &+A(144)-A(147)-A(150)-A(153)-A(155)-A(158)-A(161)+0.208*A(162)+0.33*A(165)-A(166)+0.164*A(167)-A(170)+0.285&
               &*A(171)-A(174)-A(176)-A(178)+0.5*A(179)-A(180)-A(182)-A(184)-A(185)+0.12*A(186)-A(189)+0.266*A(190)-A(193)&
               &+0.567*A(194)-A(197)-0.754*A(198)-A(199)-A(200)-A(201)-A(202)-A(203)-A(204)+0.155*A(205)-A(208)+0.378*A(209)&
               &-A(212)-A(213)-A(214)-A(215)-A(216)-A(217)-A(218)-A(219)-A(220)-A(221)-A(222)-A(223)-A(224)-A(225)-A(226)&
               &-A(227)-A(228)-A(229)-A(230)-A(231)-A(232)-A(233)
  Vdot(89) = -A(1)+A(4)-A(5)-A(6)+A(7)-A(8)+2*A(9)+2*A(10)-A(11)+A(12)+A(16)+A(23)+A(24)-A(25)+A(26)+A(28)+A(31)-A(32)&
               &+A(33)+0.61*A(34)+A(35)+0.8*A(39)+2*A(40)+A(46)+A(48)+A(51)+A(53)+A(56)+A(58)+A(65)-A(69)+A(70)+A(71)+A(73)&
               &-A(79)+A(80)+A(81)+A(83)-A(90)+A(91)+A(92)+A(94)-A(102)+A(103)+A(104)+A(106)-A(115)-A(117)-A(120)+A(128)&
               &+0.338*A(176)+A(177)+0.187*A(191)+0.474*A(195)+0.391*A(210)
  Vdot(90) = A(1)-A(4)+A(5)-A(7)-A(9)-2*A(10)+A(14)+A(15)-A(21)+A(22)-A(31)-A(46)-A(51)-A(56)-A(62)-A(71)-A(81)-A(92)&
               &-A(104)-A(128)
  Vdot(91) = -A(90)+A(91)-A(92)-A(93)-A(94)-A(95)-A(96)-A(98)-A(99)-A(100)-2*A(101)-A(113)+A(158)+A(160)
      
END SUBROUTINE Fun

! End of Fun function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


!***********************************************************************
!   Portions of Models-3/CMAQ software were developed or based on      *
!   information from various groups: Federal Government employees,     *
!   contractors working on a United States Government contract, and    *
!   non-Federal sources (including research institutions).  These      *
!   research institutions have given the Government permission to      *
!   use, prepare derivative works, and distribute copies of their      *
!   work in Models-3/CMAQ to the public and to permit others to do     *
!   so.  EPA therefore grants similar permissions for use of the       *
!   Models-3/CMAQ software, but users are requested to provide copies  *
!   of derivative works to the Government without restrictions as to   *
!   use by others.  Users are responsible for acquiring their own      *
!   copies of commercial software associated with Models-3/CMAQ and    *
!   for complying with vendor requirements.  Software copyrights by    *
!   the MCNC Environmental Modeling Center are used with their         *
!   permissions subject to the above restrictions.                     *
!***********************************************************************

! RCS file, release, date & time of last delta, author, state, [and locker]
! $Header: /project/work/rep/CCTM/src/chem/smvgear/grsubfun.F,v 1.6 2005/02/14 15:17:33 yoj Exp $ 

! what(1) key, module and SID; SCCS file; date and time of last delta:
! @@(#)grsubfun.F        1.1 /project/mod3/CMAQ/src/chem/smvgear/SCCS/s.grsubfun.  F 07 Jul 1997 12:45:32

       SUBROUTINE SUBFUN

!***********************************************************************
!
!  FUNCTION:  To Compute GLOSS = dc/dt for each species. GLOSS is the
!             net rate of change in species concentrations resulting
!             from chemical production minus chemical loss.
!
!  PRECONDITIONS: None
!                                                                     
!  KEY SUBROUTINES/FUNCTIONS CALLED: None
!
!  REVISION HISTORY: Prototype created by Jerry Gipson, June, 1995.
!                      Based on  the code originally developed by 
!                      M. Jacobson, (Atm. Env., Vol 28, No 2, 1994).
!                    Revised 3/14/96 by Jerry Gipson to conform to
!                      the Models-3 minimum IOV configuration
!                    Revised December 1996 by Jerry Gipson to conform
!                      to the Models-3 interim CTM that includes emissions
!                      in chemistry.
!                    Modified June, 1997 by Jerry Gipson to be consistent
!                      with beta CTM
!                    Modified September, 1997 by Jerry Gipson to be 
!                      consistent with the targeted CTM
!                    16 Aug 01 J.Young: Use HGRD_DEFN
!                    31 Jan 05 J.Young: get BLKSIZE from dyn alloc horizontal
!                    & vertical domain specifications module (GRID_CONF)
!***********************************************************************

!      USE GRID_CONF           ! horizontal & vertical domain specifications

      IMPLICIT NONE

!..INCLUDES:
!     INCLUDE SUBST_HGRD_ID
!     INCLUDE SUBST_VGRD_ID 
!     INCLUDE SUBST_BLKPRM
!$$$      INCLUDE SUBST_GC_SPC
!$$$      INCLUDE SUBST_RXCMMN 
!$$$      INCLUDE 'GRPARMS.EXT'
!$$$      INCLUDE 'GRVARS1.EXT'
!$$$      INCLUDE 'GRVARS2.EXT'
!$$$      INCLUDE 'GRVARS3.EXT'
      
!..ARGUMENTS: None

!..PARAMETERS: None

!..EXTERNAL FUNCTIONS: None

!..SAVED LOCAL VARIABLES: None

!..SCRATCH LOCAL VARIABLES:
      INTEGER ISP            ! Loop index for species
      INTEGER ISP1,ISP2,ISP3 ! Pointers to species numbers
      INTEGER NCELL          ! Loop index for number of cells
      INTEGER NP             ! Loop index for number of products
      INTEGER NR             ! Loop index for number of reactants
      INTEGER NRK            ! Reaction number
      INTEGER NRX            ! Loop index for number of reactions
!***********************************************************************      
      
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!  Increment call counter and initialize dcdt=gloss
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      NSUBFUN = NSUBFUN + 1
      DO ISP = 1, ISCHAN
         DO NCELL = 1, NUMCELLS
            GLOSS( NCELL, ISP ) = EMBLK( NCELL, ISP )
         ENDDO
      ENDDO
   
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!  loop over reactions and calculate rate of reaction 
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      DO 220 NRX = 1, NUSERAT( NCSP )
        NRK = NKUSERAT( NRX, NCSP )
        IF( NREACT( NRK ) .EQ. 1 ) THEN
            ISP1 = IRM2( NRK, 1, NCS )
            DO NCELL = 1, NUMCELLS
               RXRAT( NCELL, NRK ) = RK( NCELL, NRK ) *  &
                               CNEW( NCELL, ISP1 )
            ENDDO
         ELSEIF( NREACT( NRK ) .EQ. 2 ) THEN
            ISP1 = IRM2( NRK, 1, NCS )
            ISP2 = IRM2( NRK, 2, NCS )
            DO NCELL = 1, NUMCELLS
               RXRAT( NCELL, NRK ) = RK( NCELL, NRK ) * &
                               CNEW( NCELL, ISP1 ) * &
                               CNEW( NCELL, ISP2 )
            ENDDO
         ELSEIF( NREACT( NRK ) .EQ. 3 ) THEN
            ISP1 = IRM2( NRK, 1, NCS )
            ISP2 = IRM2( NRK, 2, NCS )
            ISP3 = IRM2( NRK, 3, NCS )
            DO NCELL = 1, NUMCELLS
               RXRAT( NCELL, NRK ) = RK( NCELL, NRK ) * &
                                    CNEW( NCELL, ISP1 ) *&
                                    CNEW( NCELL, ISP2 ) *&
                                    CNEW( NCELL, ISP3 )
            ENDDO 
         ELSEIF( NREACT( NRK ) .EQ. 0 ) THEN
            DO NCELL = 1, NUMCELLS
               RXRAT( NCELL, NRK ) = RK( NCELL, NRK )
            ENDDO
         ENDIF
         
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!  Subtract loss terms from gloss for this reaction 
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
         DO NR = 1, NREACT( NRK )
            ISP1 = IRM2( NRK, NR, NCS )
            DO NCELL = 1, NUMCELLS
               GLOSS( NCELL, ISP1 ) = GLOSS( NCELL, ISP1 ) - &
                                     RXRAT( NCELL, NRK )
            ENDDO
         ENDDO
  
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!  Add production terms to gloss for this reaction
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
          DO NP = 1, NPRDCT( NRK )
            ISP1 = IRM2( NRK, NP + 3, NCS )
            DO NCELL = 1, NUMCELLS
             GLOSS( NCELL, ISP1 ) = GLOSS( NCELL, ISP1 ) + &
                                   SC( NRK, NP ) * RXRAT( NCELL, NRK )
            ENDDO
         ENDDO
  220 CONTINUE               ! END LOOP OVER REACTIONS
  
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!  If the species concentration is at or below the threshold and it
!  is being destroyed, zero the loss rate.
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      DO ISP = 1, ISCHAN
         DO NCELL = 1, NUMCELLS
            IF( CNEW( NCELL, ISP ) .LE. ZBOUND .AND. &
                 GLOSS( NCELL, ISP ) .LT. 0.0 ) THEN
               GLOSS( NCELL, ISP ) = 0.0
            ENDIF
         ENDDO
      ENDDO

      RETURN

      END SUBROUTINE


END PROGRAM compare
